.. web-novel-scraper documentation master file, created by
   sphinx-quickstart on Sat Jan 18 15:00:18 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Web Novel Scraper
================================
   
This tool allows you to scrape web novels from various sources. I made it because my hands hurt from scrolling too much.

.. toctree::
   :glob:
   :includehidden:
   :maxdepth: 2

   tutorial
   concepts
   commands/index
   config_options

.. .. click:: web_novel_scraper.__main__:cli
..    :prog: web-novel-scraper
..    :nested: full